@@ -35,9 +35,15 @@ class Schroot(object):
         ])
         self.__session = cmd.stdout.read()[:-1]
 
-    def run_cmd(self, *args):
+    def run_cmd(self, *args, **kwargs):
+        if 'directory' in kwargs:
+            directory = kwargs['directory']
+        else:
+            directory = '/'
+
         cmd = Schroot.MyPopen([
             SCHROOT_BIN,
+            '-d', directory,
             '-r',
             '-c', self.__session,
             '--' ] + list(args)
